==> net.bluemind.p2.we.settings-4.9.3879.zip: net/bluemind/addressbook/api/gwt/serder/VCardBasicAttributeGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.addressbook.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VCardBasicAttributeGwtSerDer implements GwtSerDer<net.bluemind.addressbook.api.VCard.BasicAttribute> {

	public VCardBasicAttributeGwtSerDer( ) {
	}

	@Override
	public net.bluemind.addressbook.api.VCard.BasicAttribute deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.addressbook.api.VCard.BasicAttribute ret = new net.bluemind.addressbook.api.VCard.BasicAttribute();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute ret, JSONObject json) {

		JSONValue parametersJSON = json.get("parameters");
		ret.parameters =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).deserialize(parametersJSON);
		JSONValue valueJSON = json.get("value");
		ret.value =  GwtSerDerUtils.STRING.deserialize(valueJSON);
	}

	@Override
	public JSONValue serialize(net.bluemind.addressbook.api.VCard.BasicAttribute o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute o, JSONObject ret) {

		ret.put("parameters",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).serialize( o.parameters ));
		ret.put("value",  GwtSerDerUtils.STRING.serialize( o.value ));
	}
}

==> net.bluemind.p2.we.settings-5.5.3112.zip: net/bluemind/addressbook/api/gwt/serder/VCardBasicAttributeGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.addressbook.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class VCardBasicAttributeGwtSerDer implements GwtSerDer<net.bluemind.addressbook.api.VCard.BasicAttribute> {

	public VCardBasicAttributeGwtSerDer( ) {
	}

	@Override
	public net.bluemind.addressbook.api.VCard.BasicAttribute deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.addressbook.api.VCard.BasicAttribute ret = new net.bluemind.addressbook.api.VCard.BasicAttribute();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute ret, JSONObject json) {
		JSONValue parametersJSON = json.get("parameters");
		ret.parameters =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).deserialize(parametersJSON);
		JSONValue valueJSON = json.get("value");
		ret.value =  GwtSerDerUtils.STRING.deserialize(valueJSON);
	}

	public void deserializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute ret, JSONObject json, Set<String> childPropertiesToIgnore) {
		if (!childPropertiesToIgnore.contains("parameters")) {
			JSONValue parametersJSON = json.get("parameters");
			ret.parameters =  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).deserialize(parametersJSON);
		}
		if (!childPropertiesToIgnore.contains("value")) {
			JSONValue valueJSON = json.get("value");
			ret.value =  GwtSerDerUtils.STRING.deserialize(valueJSON);
		}
	}


	@Override
	public JSONValue serialize(net.bluemind.addressbook.api.VCard.BasicAttribute o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute o, JSONObject ret) {

		ret.put("parameters",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).serialize( o.parameters ));
		ret.put("value",  GwtSerDerUtils.STRING.serialize( o.value ));
	}

	public void serializeTo(net.bluemind.addressbook.api.VCard.BasicAttribute o, JSONObject ret, Set<String> childPropertiesToIgnore) {

		if (!childPropertiesToIgnore.contains("parameters")) {
			ret.put("parameters",  new GwtSerDerUtils.ListSerDer<>(new net.bluemind.addressbook.api.gwt.serder.VCardParameterGwtSerDer()).serialize( o.parameters ));
		}
		if (!childPropertiesToIgnore.contains("value")) {
			ret.put("value",  GwtSerDerUtils.STRING.serialize( o.value ));
		}
	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
